@@ -1,10 +1,4 @@
-from trame import state, controller as ctrl
-from trame.html.widgets import ListBrowser
-
-try:
-    from paraview import simple
-except:
-    simple = None
+from trame.widgets.trame import ListBrowser
 
 SOURCES = [
     "Cone",
@@ -22,15 +16,16 @@ FILTERS = [
 
 
 class Algorithms(ListBrowser):
-    def __init__(self, add_defaults=True, **kwargs):
+    def __init__(self, add_defaults=True, click=None, **kwargs):
         super().__init__(
             list=("algorithm_list", []),
             click=(self._click, "[$event.value]"),
             **kwargs,
         )
+        self._click_fn = click
 
         if add_defaults:
-            state.algorithm_list = []
+            self.server.state.algorithm_list = []
             for name in SOURCES:
                 self.add_source(name)
             for name in FILTERS:
@@ -44,13 +39,10 @@ class Algorithms(ListBrowser):
 
     def add_entry(self, **kwargs):
         """Possible keys: text, prependIcon and appendIcon"""
-        state.algorithm_list += [kwargs]
+        self.server.state.algorithm_list += [kwargs]
 
     def _click(self, index):
-        entry = state.algorithm_list[index]
+        entry = self.server.state.algorithm_list[index]
         name = entry.get("text")
-        newProxy = simple.__dict__[name]()
-        rep = simple.Show(newProxy)
-
-        # Use life cycle handler
-        ctrl.on_data_change()
+        if self._click_fn:
+            self._click_fn(name)
